FormError class

Error information about why a form operation failed.

Constructors

FormError({required int errorCode, required String message})
Init a FormError with the errorCode and message.

Properties

errorCode → int
Code for the error.
final
hashCode → int
The hash code for this object.
no setteroverride
message → String
The message describing the error.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override